@@ -27,17 +27,17 @@ class DirectionCanvas : public QWidget
         explicit DirectionCanvas(QWidget* parent = nullptr);
 		void enableGreyTurtle(bool);
 
-	public slots:
+	public Q_SLOTS:
 		void updateDirections(double previousDeg, double deg);
 	
-	signals:
+    Q_SIGNALS:
 		void degreeChanged(double deg);
 		void previousDegreeChanged(double deg);
 
 	protected:
-		void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
-		void mouseMoveEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
-		void mousePressEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
+		void paintEvent(QPaintEvent *event) override;
+		void mouseMoveEvent(QMouseEvent *event) override;
+		void mousePressEvent(QMouseEvent *event) override;
 
 	private:
 		double translateMouseCoords(double x, double y);
@@ -63,7 +63,7 @@ class DirectionDialog : public QDialog
 			Direction = 2
 		};
 
-	signals:
+    Q_SIGNALS:
 		void pasteText(const QString&);
 
 	private:
@@ -87,7 +87,7 @@ class DirectionDialog : public QDialog
 		void updateCanvas();
 		void updateCommandBox();
 
-	private slots:
+	private Q_SLOTS:
 		void directionChanged(int value);
 		void changeCommand(int command);
 		void updateDegrees(double deg);
